@@ -18,8 +18,9 @@ from attune_project_api.items.step_tuples.step_sql_oracle_tuple import (
     StepSqlOracleTuple,
 )
 from attune_project_api.migration import runMigrationsForStorageContext
-from .git_lib_mixin import GitLibMixin
+from .GitLibMixin import GitLibMixin
 from ..Exceptions import ItemNotFoundError
+from ..Exceptions import ProjectIncorrectVersionError
 from ..Exceptions import ProjectValidationError
 from ..ObjectStorageContext import ContextProjectInfo
 from ..ObjectStorageContext import ObjectStorageContext
@@ -33,6 +34,7 @@ from .._private.utils import makeStorageKey
 from ..items.file_archive_tuples.file_tuple_constants import (
     FileArchiveTupleTypeEnum,
 )
+from ..migration import checkIfLibrarySupportsRevision
 
 
 logger = logging.getLogger(__name__)
@@ -261,6 +263,13 @@ class GitObjectStorageContext(
         self.__projectInfo = info
         GitLibMixin.__init__(self, projectPath)
 
+        revision = self.getRevision()
+        if not checkIfLibrarySupportsRevision(revision):
+            raise ProjectIncorrectVersionError(
+                "A newer version of Attune is "
+                f"required to load the {info.name} project"
+            )
+
         """ This is equivalent to an Identity Map in SqlAlchemy Session
         Holds references to all instances fetched from the storage
         ensuring that "one and only one" reference exists for an item
@@ -285,6 +294,15 @@ class GitObjectStorageContext(
         self.__loadItems(ItemStorageGroupEnum.FileArchive)
         self.__loadItems(ItemStorageGroupEnum.Step)
 
+    def reloadProject(self) -> None:
+        self.__instanceByKeyByGroup[ItemStorageGroupEnum.Step] = {}
+        self.__instanceByKeyByGroup[ItemStorageGroupEnum.Parameter] = {}
+        self.__instanceByKeyByGroup[ItemStorageGroupEnum.FileArchive] = {}
+
+        self.__loadItems(ItemStorageGroupEnum.Parameter)
+        self.__loadItems(ItemStorageGroupEnum.FileArchive)
+        self.__loadItems(ItemStorageGroupEnum.Step)
+
     @property
     def project(self) -> ContextProjectInfo:
         return self.__projectInfo
@@ -468,6 +486,8 @@ class GitObjectStorageContext(
             self.__storeReferenceToTuple(item)
 
         if errors:
+            for error in errors:
+                logger.info(f"Project load error: {error}")
             raise ProjectValidationError(errors)
 
         logger.debug(
